<template>
  <LoadingLayout :loading="isLoading">
    <div
      class="result-wrapper"
      v-if="myCertificationAuditInfo?.frontStatus === UserCertificationFrontStatus.NotCertified"
    >
      <div class="result-title">未认证</div>
    </div>
    <div
      class="result-wrapper"
      v-else-if="myCertificationAuditInfo?.frontStatus === UserCertificationFrontStatus.Certified"
    >
      <img class="result-icon" :src="IconSuccess" />
      <div class="result-title">认证成功</div>
      <div class="result-subtitle">您的企业实名已认证成功</div>
      <PageFooterBtn type="primary" class="result-btn" @click="goUserCenter"
        >返回个人中心</PageFooterBtn
      >
    </div>
    <div
      class="result-wrapper"
      v-else-if="myCertificationAuditInfo?.frontStatus === UserCertificationFrontStatus.Rejected"
    >
      <img class="result-icon" :src="IconError" />
      <div class="result-title">认证失败</div>
      <div class="result-subtitle">您的企业实名认证失败</div>
      <div class="result-subtitle">失败原因：{{ myCertificationAuditInfo?.auditNote ?? '' }}</div>
      <PageFooterBtn type="primary" class="result-btn" @click="goBack()"
        >重新提交认证</PageFooterBtn
      >
    </div>
  </LoadingLayout>
</template>

<script setup lang="ts">
import { useMyCertificationAuditInfo, useSwitchTab } from '@/hooks';
import Taro from '@tarojs/taro';
import { goBack } from '@/utils';
import IconSuccess from '@/assets/authentication/icon-result-success.png';
import IconError from '@/assets/authentication/icon-result-error.png';
import { UserCertificationFrontStatus } from '@12333/constants';

defineOptions({
  name: 'InnerPage',
});

const { myCertificationAuditInfo, isLoading } = useMyCertificationAuditInfo();

const switchTab = useSwitchTab();

function goUserCenter() {
  switchTab({
    url: RouterPath.mine,
  });
}
</script>

<style lang="scss">
@import '@/styles/common.scss';

.authenticationResult-page-wrapper {
  .result-wrapper {
    display: flex;
    flex-direction: column;
    align-items: center;
    padding-top: 150px;

    .result-icon {
      width: 320px;
      height: 184px;
      object-fit: cover;
      margin-bottom: 12px;
    }

    .result-title {
      font-weight: 400;
      font-size: 32px;
      color: boleGetCssVar('text-color', 'primary');
      line-height: 32px;
      margin-bottom: 32px;
    }

    .result-subtitle {
      font-weight: 400;
      font-size: 28px;
      color: boleGetCssVar('text-color', 'regular');
      line-height: 44px;
      margin-bottom: 40px;
    }

    .result-btn {
      width: 542px;
      font-size: 28px;
    }
  }
}
</style>
